#!/bin/bash
#
# This script is called by the LAN Provider everytime the lan1/lan2 ipaddress is 
# changed to DHCP through EM or Console. It will start voicemail after the system 
# configuration has changed and the PDR has been updated with the new ip address.
#
# Included as part of fix for CR Q01286989-01 by Pranab Bohra on 23rd May 2006. 
#****************************************************************************************


INTERFACE=""

if [ $1 = "eth0" ]; then
   INTERFACE="lan1"
elif [ $1 = "eth1" ]; then 
   INTERFACE="lan2"
else
   echo "This is an invalid interface name."
   exit 2 
fi

COMMAND="pdrcmd get networkinterfaces\\lan\\$INTERFACE\\lastupdate"
NEWUPDATE="`$COMMAND`"
OLDUPDATE="$NEWUPDATE"
COUNT=0
TIME_OUT=20
SUCCESS=0

# Loop until the ipaddress is changed by the DHCP Provider or we time out. Time out value has been set to 20
while [ "$COUNT" -lt "$TIME_OUT" ]
do
  NEWUPDATE="`$COMMAND`" # Execute the pdrcmd to get the "lastupdate" value for the interface.
  # Start both voicemail and IVR if the PDR has been updated with a new "lastupdate" value
  if [ "$NEWUPDATE" != "$OLDUPDATE" ]; then
     COUNT="$TIME_OUT"
     echo `date` "DHCP settings have been updated, restarting voicemail " >> /var/log/LAN.log
     /nn/bin/processcontrol start voicemail
     if [ $? -ne 0 ]; then
        echo "`date` voicemail startup failed, please check voicemail logs. " >> /var/log/LAN.log
     fi
     SUCCESS=1
  else
     sleep 1
     let "COUNT+=1"
     SUCCESS=0
  fi
done

if [ "$SUCCESS" -eq 0 ]; then
  echo `date` "Time out!! IP address did not change after 20 seconds, exiting without starting voicemail" >> /var/log/LAN.log
fi

exit $SUCCESS
